@@ -2,20 +2,20 @@ package Process::Delegatable;
 
 use strict;
 use base 'Process::Storable';
-use Storable   ();
-use File::Temp ();
-use IPC::Run3  ();
-use Perl::Exe  ();
+use Storable    ();
+use File::Temp  ();
+use IPC::Run3   ();
+use Probe::Perl ();
 
 use vars qw{$VERSION @PERLCMD};
 BEGIN {
-	$VERSION = '0.21';
+	$VERSION = '0.22';
 
 	# Contains the command to use to launch perl
 	# Should be the path to the perl current running.
 	# People with special needs should localise this
 	# to add any flags.
-	@PERLCMD = ( Perl::Exe::find );
+	@PERLCMD = ( Probe::Perl->find_perl_interpreter );
 }
 
 sub delegate {
